@@ -42,7 +42,8 @@ def init(system_kwargs, backend_kwargs):
     pslogger.log('initializing multiprocessing pool with {} processes'.format(ncores), stderr=verbose)
     pslogger.log('Pool() kwargs are', backend_kwargs, stderr=verbose > 1)
 
-    pool = multiprocessing.Pool(**backend_kwargs)
+    ctx = multiprocessing.get_context('spawn')
+    pool = ctx.Pool(**backend_kwargs)
     global finalize_needed
     finalize_needed = True
 
@@ -174,7 +175,7 @@ def progress_until_fewer(cores, factor, out_func, system_stats, system_kwargs, u
     progress = system_kwargs['progress']
 
     while system_kwargs['outstanding'] > cores*factor:
-        time.sleep(0.1)
+        time.sleep(0.001)  # apparently needs to be short to avoid a hang if verbose 
         progress.report()
         system_stats.report()
 
