@@ -11,14 +11,24 @@ if [ ! -z "$ONLY_BUILTINS" ]; then
     exit 0
 fi
 
-PORT=6379
+# ray 1.13 introduced the following:
+ray disable-usage-stats || /bin/true
+
+RPORT=6379
+OPORT=8076
+CLIENT=10001
+
 REDIS_PASSWORD=thehfhghedhdjfhgfhdhdhdf
-echo $(hostname):$PORT $REDIS_PASSWORD > ~/.ray-test-72363726-details
+# should this be RPORT or OPORT?
+# RPORT works with ray 1.15
+echo $(hostname):$RPORT $REDIS_PASSWORD > ~/.ray-test-72363726-details
 
 GIGABYTE=1000000000  # close enough
 
 ray stop  # in case there's an a leftover ray
-ray start --head --port=$PORT --redis-password=$REDIS_PASSWORD --memory $GIGABYTE --object-store-memory $GIGABYTE --redis-max-memory $GIGABYTE $RAY_START_EXTRAS
+
+# --include-dashboard starts at ray 1.13
+ray start --head --port=$RPORT --object-manager-port=$OPORT --redis-password=$REDIS_PASSWORD --memory $GIGABYTE --object-store-memory $GIGABYTE --redis-max-memory $GIGABYTE $RAY_START_EXTRAS
 
 # in order to find both the uninstalled paramsurvey and our test program,
 # which ray needs to pickle, the PYTHONPATH must be manipulated. See
