@@ -31,6 +31,7 @@ def readouterr_and_dump(capsys):
 
 
 def test_basics(paramsurvey_init):
+    assert os.environ['OMP_NUM_THREADS'] == '1'
     ncores = max(4, paramsurvey.current_core_count())
 
     duration = 0.1
@@ -307,14 +308,14 @@ def test_map_ncores(paramsurvey_init):
 
 @pytest.mark.skip(reason='cannot call paramsurvey.init twice in a session')
 def test_invalid_kwarg_init():
-    with pytest.raises(TypeError):
+    with pytest.raises((TypeError, ValueError)):  # ValueError in ray >= 1.15.0
         paramsurvey.init(doesnotexist=True)
 
 
 def test_invalid_kwarg(paramsurvey_init):
-    with pytest.raises(TypeError):
+    with pytest.raises((TypeError, ValueError)):  # ValueError in ray >= 1.15.0
         paramsurvey.map(sleep_worker, [{}], doesnotexist=True)
-    with pytest.raises(TypeError):
+    with pytest.raises((TypeError, ValueError)):  # ValueError in ray >= 1.15.0
         paramsurvey.map(sleep_worker, [{}], ray={'doesnotexist': True}, multiprocessing={'doesnotexist': True})
 
 
@@ -401,5 +402,5 @@ def test_pset_backend_args():
     assert next(results.itertuples()).r == 'PASS', 'worker saw ray backend pset config'
 
     psets = [{'foo': 1, 'ray': {'thisoptiondoesnotexist': 1}}]
-    with pytest.raises(TypeError):
+    with pytest.raises((TypeError, ValueError)):  # ValueError ray >= 1.15.0
         results = paramsurvey.map(worker_pset_backend_args, psets, name='test_pset_backend_args')
